.. Automatically generated by nengo-bones, do not edit this file directly

***************************
PyTorchSpiking contributors
***************************

See https://github.com/nengo/pytorch-spiking/graphs/contributors
for a list of the people who have committed to PyTorchSpiking.
Thank you for your contributions!

For the full list of the many contributors to the Nengo ecosystem,
see https://www.nengo.ai/people/.
